==> ml_algo-15.2.4.tar.gz: lib/src/classifier/decision_tree_classifier/_init_module.dart <==
import 'package:ml_algo/src/classifier/decision_tree_classifier/_injector.dart';
import 'package:ml_algo/src/classifier/decision_tree_classifier/decision_tree_classifier_factory.dart';
import 'package:ml_algo/src/classifier/decision_tree_classifier/decision_tree_classifier_factory_impl.dart';
import 'package:ml_algo/src/common/sequence_elements_distribution_calculator/distribution_calculator_factory.dart';
import 'package:ml_algo/src/common/sequence_elements_distribution_calculator/distribution_calculator_factory_impl.dart';
import 'package:ml_algo/src/di/common/init_common_module.dart';
import 'package:ml_algo/src/di/injector.dart';
import 'package:ml_algo/src/tree_trainer/leaf_detector/leaf_detector_factory.dart';
import 'package:ml_algo/src/tree_trainer/leaf_detector/leaf_detector_factory_impl.dart';
import 'package:ml_algo/src/tree_trainer/leaf_label/leaf_label_factory_factory.dart';
import 'package:ml_algo/src/tree_trainer/leaf_label/leaf_label_factory_factory_impl.dart';
import 'package:ml_algo/src/tree_trainer/split_assessor/split_assessor_factory.dart';
import 'package:ml_algo/src/tree_trainer/split_assessor/split_assessor_factory_impl.dart';
import 'package:ml_algo/src/tree_trainer/split_selector/split_selector_factory.dart';
import 'package:ml_algo/src/tree_trainer/split_selector/split_selector_factory_impl.dart';
import 'package:ml_algo/src/tree_trainer/splitter/nominal_splitter/nominal_splitter_factory.dart';
import 'package:ml_algo/src/tree_trainer/splitter/nominal_splitter/nominal_splitter_factory_impl.dart';
import 'package:ml_algo/src/tree_trainer/splitter/numerical_splitter/numerical_splitter_factory.dart';
import 'package:ml_algo/src/tree_trainer/splitter/numerical_splitter/numerical_splitter_factory_impl.dart';
import 'package:ml_algo/src/tree_trainer/splitter/splitter_factory.dart';
import 'package:ml_algo/src/tree_trainer/splitter/splitter_factory_impl.dart';
import 'package:ml_algo/src/tree_trainer/tree_trainer_factory.dart';
import 'package:ml_algo/src/tree_trainer/tree_trainer_factory_impl.dart';

void initDecisionTreeModule() {
  initCommonModule();

  decisionTreeInjector
    ..clearAll()
    ..registerSingleton<SequenceElementsDistributionCalculatorFactory>(
            () => const SequenceElementsDistributionCalculatorFactoryImpl())

    ..registerSingleton<NominalTreeSplitterFactory>(
            () => const NominalTreeSplitterFactoryImpl())

    ..registerSingleton<NumericalTreeSplitterFactory>(
            () => const NumericalTreeSplitterFactoryImpl())

    ..registerSingleton<TreeSplitAssessorFactory>(
            () => const TreeSplitAssessorFactoryImpl())

    ..registerSingleton<TreeSplitterFactory>(
            () => TreeSplitterFactoryImpl(
          decisionTreeInjector.get<TreeSplitAssessorFactory>(),
          decisionTreeInjector.get<NominalTreeSplitterFactory>(),
          decisionTreeInjector.get<NumericalTreeSplitterFactory>(),
        ))

    ..registerSingleton<TreeSplitSelectorFactory>(
            () => TreeSplitSelectorFactoryImpl(
          decisionTreeInjector.get<TreeSplitAssessorFactory>(),
          decisionTreeInjector.get<TreeSplitterFactory>(),
        ))

    ..registerSingleton<TreeLeafDetectorFactory>(
            () => TreeLeafDetectorFactoryImpl(
          decisionTreeInjector.get<TreeSplitAssessorFactory>(),
        ))

    ..registerSingleton<TreeLeafLabelFactoryFactory>(
            () => TreeLeafLabelFactoryFactoryImpl(
          decisionTreeInjector
              .get<SequenceElementsDistributionCalculatorFactory>(),
        ))

    ..registerSingleton<TreeTrainerFactory>(
            () => TreeTrainerFactoryImpl(
          decisionTreeInjector.get<TreeLeafDetectorFactory>(),
          decisionTreeInjector.get<TreeLeafLabelFactoryFactory>(),
          decisionTreeInjector.get<TreeSplitSelectorFactory>(),
        ))

    ..registerSingleton<DecisionTreeClassifierFactory>(
            () => const DecisionTreeClassifierFactoryImpl());
}

==> ml_algo-15.3.2.tar.gz: lib/src/classifier/decision_tree_classifier/_init_module.dart <==
import 'package:ml_algo/src/classifier/decision_tree_classifier/_injector.dart';
import 'package:ml_algo/src/classifier/decision_tree_classifier/decision_tree_classifier_factory.dart';
import 'package:ml_algo/src/classifier/decision_tree_classifier/decision_tree_classifier_factory_impl.dart';
import 'package:ml_algo/src/common/distribution_calculator/distribution_calculator_factory.dart';
import 'package:ml_algo/src/common/distribution_calculator/distribution_calculator_factory_impl.dart';
import 'package:ml_algo/src/di/common/init_common_module.dart';
import 'package:ml_algo/src/tree_trainer/leaf_detector/leaf_detector_factory.dart';
import 'package:ml_algo/src/tree_trainer/leaf_detector/leaf_detector_factory_impl.dart';
import 'package:ml_algo/src/tree_trainer/leaf_label/leaf_label_factory_factory.dart';
import 'package:ml_algo/src/tree_trainer/leaf_label/leaf_label_factory_factory_impl.dart';
import 'package:ml_algo/src/tree_trainer/split_assessor/split_assessor_factory.dart';
import 'package:ml_algo/src/tree_trainer/split_assessor/split_assessor_factory_impl.dart';
import 'package:ml_algo/src/tree_trainer/split_selector/split_selector_factory.dart';
import 'package:ml_algo/src/tree_trainer/split_selector/split_selector_factory_impl.dart';
import 'package:ml_algo/src/tree_trainer/splitter/nominal_splitter/nominal_splitter_factory.dart';
import 'package:ml_algo/src/tree_trainer/splitter/nominal_splitter/nominal_splitter_factory_impl.dart';
import 'package:ml_algo/src/tree_trainer/splitter/numerical_splitter/numerical_splitter_factory.dart';
import 'package:ml_algo/src/tree_trainer/splitter/numerical_splitter/numerical_splitter_factory_impl.dart';
import 'package:ml_algo/src/tree_trainer/splitter/splitter_factory.dart';
import 'package:ml_algo/src/tree_trainer/splitter/splitter_factory_impl.dart';
import 'package:ml_algo/src/tree_trainer/tree_trainer_factory.dart';
import 'package:ml_algo/src/tree_trainer/tree_trainer_factory_impl.dart';

void initDecisionTreeModule() {
  initCommonModule();

  decisionTreeInjector
    ..clearAll()
    ..registerSingleton<DistributionCalculatorFactory>(
            () => const DistributionCalculatorFactoryImpl())

    ..registerSingleton<NominalTreeSplitterFactory>(
            () => const NominalTreeSplitterFactoryImpl())

    ..registerSingleton<NumericalTreeSplitterFactory>(
            () => const NumericalTreeSplitterFactoryImpl())

    ..registerSingleton<TreeSplitAssessorFactory>(
            () => const TreeSplitAssessorFactoryImpl())

    ..registerSingleton<TreeSplitterFactory>(
            () => TreeSplitterFactoryImpl(
          decisionTreeInjector.get<TreeSplitAssessorFactory>(),
          decisionTreeInjector.get<NominalTreeSplitterFactory>(),
          decisionTreeInjector.get<NumericalTreeSplitterFactory>(),
        ))

    ..registerSingleton<TreeSplitSelectorFactory>(
            () => TreeSplitSelectorFactoryImpl(
          decisionTreeInjector.get<TreeSplitAssessorFactory>(),
          decisionTreeInjector.get<TreeSplitterFactory>(),
        ))

    ..registerSingleton<TreeLeafDetectorFactory>(
            () => TreeLeafDetectorFactoryImpl(
          decisionTreeInjector.get<TreeSplitAssessorFactory>(),
        ))

    ..registerSingleton<TreeLeafLabelFactoryFactory>(
            () => TreeLeafLabelFactoryFactoryImpl(
          decisionTreeInjector
              .get<DistributionCalculatorFactory>(),
        ))

    ..registerSingleton<TreeTrainerFactory>(
            () => TreeTrainerFactoryImpl(
          decisionTreeInjector.get<TreeLeafDetectorFactory>(),
          decisionTreeInjector.get<TreeLeafLabelFactoryFactory>(),
          decisionTreeInjector.get<TreeSplitSelectorFactory>(),
        ))

    ..registerSingleton<DecisionTreeClassifierFactory>(
            () => const DecisionTreeClassifierFactoryImpl());
}
